"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const React = tslib_1.__importStar(require("react"));
const react_native_1 = require("react-native");
/**
 * ? Local Imports
 */
const Icon_1 = tslib_1.__importDefault(require("./components/Icon"));
const RNSingleSelect_style_1 = tslib_1.__importStar(require("./RNSingleSelect.style"));
const theme_1 = require("./theme");
const utils_1 = require("./utils");
let iconRef = undefined;
const RNSingleSelect = (props) => {
    const [selectedItem, setSelectedItem,] = React.useState(null);
    const [menuToggled, setMenuToggled] = React.useState(false);
    const [dataBackup, setDataBackup] = React.useState(props.data);
    const [dataSource, setDataSource] = React.useState(props.data);
    const [borderRadiusAnimation, setBorderRadiusAnimation] = React.useState(new react_native_1.Animated.Value(16));
    const [menuBarYTranslateAnimation, setMenuBarYTranslateAnimation,] = React.useState(new react_native_1.Animated.Value(0));
    const [theme, setTheme] = React.useState(theme_1.DARK);
    const { menuBarContainerHeight = 150, menuBarContainerWidth = 250, disableAbsolute = false, ImageComponent = react_native_1.Image, TextComponent = react_native_1.Text, disableFilterAnimation = false, } = props;
    React.useEffect(() => {
        if (props.darkMode)
            setTheme(theme_1.DARK);
        else
            setTheme(theme_1.LIGHT);
    }, []);
    const animateBorderRadius = () => {
        react_native_1.Animated.timing(borderRadiusAnimation, {
            toValue: menuToggled ? 16 : 0,
            duration: 1250,
            easing: react_native_1.Easing.bounce,
            useNativeDriver: true,
        }).start();
    };
    const animateSelectionBar = () => {
        react_native_1.Animated.timing(menuBarYTranslateAnimation, {
            toValue: menuToggled ? 0 : 100,
            duration: 250,
            easing: react_native_1.Easing.ease,
            useNativeDriver: true,
        }).start();
    };
    const handleOnToggleMenuBar = (isMenuToggled) => {
        iconRef?.onPressAnimation();
        animateBorderRadius();
        animateSelectionBar();
        setMenuToggled(isMenuToggled ? isMenuToggled : !menuToggled);
    };
    const handleOnSelectItem = (item) => {
        handleOnFilter("");
        setSelectedItem(item);
        handleOnToggleMenuBar();
        props.onSelect && props.onSelect(item);
    };
    const triggerFilterAnimation = () => {
        react_native_1.LayoutAnimation.configureNext({
            duration: 1000,
            create: {
                type: react_native_1.LayoutAnimation.Types.spring,
                property: react_native_1.LayoutAnimation.Properties.opacity,
                springDamping: 1,
            },
            delete: {
                type: react_native_1.LayoutAnimation.Types.spring,
                property: react_native_1.LayoutAnimation.Properties.opacity,
                springDamping: 1,
            },
        });
    };
    const handleOnFilter = (text) => {
        const newData = utils_1.filterBySearch(text, props.data);
        console.log("newData: ", newData);
        !disableFilterAnimation && triggerFilterAnimation();
        setSelectedItem({ value: text });
        setDataSource(newData);
    };
    /* -------------------------------------------------------------------------- */
    /*                               Render Methods                               */
    /* -------------------------------------------------------------------------- */
    const renderSingleSelectButton = () => {
        return (<react_native_1.TouchableOpacity onPress={() => {
            handleOnToggleMenuBar();
        }} {...props}>
        <react_native_1.Animated.View style={[
            RNSingleSelect_style_1._menuButtonContainer(theme, props.height, props.width),
            {
                borderRadius: borderRadiusAnimation,
            },
            props.buttonContainerStyle,
        ]}>
          <react_native_1.View style={RNSingleSelect_style_1.default.buttonContainerGlue}>
            <react_native_1.TextInput placeholderTextColor={selectedItem
            ? theme_1.ThemeColors[theme].textColor
            : theme_1.ThemeColors[theme].placeholderColor} style={RNSingleSelect_style_1._placeholderTextStyle(theme, selectedItem)} placeholder={props.placeholder || "Select"} onFocus={() => handleOnToggleMenuBar(false)} onChangeText={(text) => {
            if (text.length === 0)
                handleOnFilter("");
            else
                handleOnFilter(text);
        }}>
              <TextComponent>{selectedItem?.value}</TextComponent>
            </react_native_1.TextInput>
            <Icon_1.default theme={theme} ref={(ref) => (iconRef = ref)} style={[RNSingleSelect_style_1.default.arrowImageStyle, props.arrowImageStyle]}/>
          </react_native_1.View>
        </react_native_1.Animated.View>
      </react_native_1.TouchableOpacity>);
    };
    const renderMenuItem = (menuItem) => {
        const { index } = menuItem;
        const { id, value, imageSource } = menuItem.item;
        const { data, imageWidth, imageHeight, menuItemTextStyle } = props;
        return (<react_native_1.TouchableHighlight key={id} style={RNSingleSelect_style_1._menuItemContainer(index, data)} onPress={() => {
            handleOnSelectItem(item);
        }}>
        <react_native_1.View style={RNSingleSelect_style_1.default.menuBarItemContainerGlue}>
          {imageSource && (<ImageComponent resizeMode="contain" source={imageSource} style={RNSingleSelect_style_1._imageStyle(imageHeight, imageWidth)}/>)}
          <TextComponent style={[RNSingleSelect_style_1._menuItemTextStyle(theme), menuItemTextStyle]}>
            {value}
          </TextComponent>
        </react_native_1.View>
      </react_native_1.TouchableHighlight>);
    };
    const renderMenuBar = () => {
        const rotate = menuBarYTranslateAnimation.interpolate({
            inputRange: [0, 25, 50, 75, 100],
            outputRange: [0, 0.5, 0.75, 0.9, 1],
        });
        return (<react_native_1.Animated.View style={[
            RNSingleSelect_style_1._menuBarContainer(theme, menuBarContainerHeight, menuBarContainerWidth),
            {
                transform: [{ scaleY: rotate }],
                display: disableAbsolute ? "flex" : menuToggled ? "flex" : "none",
            },
            props.menuBarContainerStyle,
        ]}>
        <react_native_1.FlatList data={dataSource} renderItem={renderMenuItem}/>
      </react_native_1.Animated.View>);
    };
    return (<react_native_1.View>
      {renderSingleSelectButton()}
      {renderMenuBar()}
    </react_native_1.View>);
};
exports.default = RNSingleSelect;
//# sourceMappingURL=RNSingleSelect.js.map